"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSyntaxHighlighter = useSyntaxHighlighter;
var _react = require("react");
var _syntax = require("../syntax");
function useSyntaxHighlighter({
  text,
  lang,
  langName,
  theme,
  themeName
}) {
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)();
  const [isLoading, setIsLoading] = (0, _react.useState)(true);
  (0, _react.useEffect)(() => {
    let mounted = true;
    setIsLoading(true);
    async function highlight() {
      if (!text) {
        setIsLoading(false);
        setTokens([]);
        return;
      }
      try {
        const highlighter = await (0, _syntax.createHighlighter)({
          langs: [lang],
          themes: [theme]
        });
        const result = highlighter.codeToTokens(text, {
          lang: langName,
          theme: themeName
        });
        if (mounted && result.tokens) {
          setTokens(result.tokens);
          setError(undefined);
        }
      } catch (err) {
        console.error('Highlighting error:', err);
        if (mounted) {
          setError(err instanceof Error ? err.message : 'Syntax highlighting failed');
          setTokens([]);
        }
      } finally {
        if (mounted) {
          setIsLoading(false);
        }
      }
    }
    highlight();
    return () => {
      mounted = false;
    };
  }, [text, lang, langName, theme, themeName]);
  return {
    tokens,
    error,
    isLoading
  };
}
//# sourceMappingURL=useSyntaxHighlighter.js.map