import type { SyntaxHighlighterProps } from 'src/types/shiki'
import type { ReactStyle } from '../../utils/style-transformer'
import React, { useMemo } from 'react'
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native'
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter'
import { getRNStylesFromShikiStyle } from '../../utils/style-transformer'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

const styles = StyleSheet.create({
  scrollView: {
    flex: 1,
    minHeight: 20,
  },
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
})

const SyntaxHighlighter: React.FC<SyntaxHighlighterProps> = ({ text, language, languageId, theme }) => {
  console.log('theme:', theme)
  const stylesheet = useMemo(() => {
    const styles = getRNStylesFromShikiStyle(theme as ReactStyle)
    console.log('Generated stylesheet:', styles)
    return styles
  }, [theme])

  const { tokens } = useSyntaxHighlighter({
    text,
    language,
    languageId,
    theme,
  })

  const renderToken = (token: any, index: number, lineIndex: number) => {
    // Ensure to collect all styles associated with the token's scopes
    const tokenScopes = Array.isArray(token.scope) ? token.scope : [token.scope]
    const tokenStylesArray = tokenScopes.map((scope: string) => stylesheet[scope] || {})
    const combinedStyles = StyleSheet.flatten([
      ...tokenStylesArray,
      {
        fontFamily: monospaceFont,
      },
      ...(token.color && { color: token.color }),
      ...(token.fontStyle === 'italic' ? [{ fontStyle: 'italic' }] : []),
      ...(token.fontStyle === 'bold' ? [{ fontWeight: 'bold' }] : []),
    ])

    console.log(`Rendering token: ${token.content}, styles:`, combinedStyles)

    return (
      <Text key={`${lineIndex}-${index}`} style={combinedStyles}>
        {token.content.replace(/ /g, '\u00A0')}
      </Text>
    )
  }

  // In the renderLine and renderToken flow
  const renderLine = (line: any[], lineIndex: number) => {
    console.log(`Rendering line ${lineIndex}:`, line)
    return (
      <View key={lineIndex} style={styles.lineContainer}>
        {line.map((token, tokenIndex) => renderToken(token, tokenIndex, lineIndex))}
      </View>
    )
  }

  return (
    <ScrollView horizontal showsHorizontalScrollIndicator={Platform.OS !== 'web'} style={styles.scrollView}>
      <View onStartShouldSetResponder={() => true}>{tokens.map((line, index) => renderLine(line, index))}</View>
    </ScrollView>
  )
}

export default SyntaxHighlighter
