import type { LanguageInput, ThemedToken, ThemeInput } from 'shiki'
import type { TokenType } from '../types/shiki'
import { createHighlighterCore } from 'shiki/dist/core.mjs'
import { createJavaScriptRegexEngine } from 'shiki/dist/engine-javascript.mjs'

const engine = createJavaScriptRegexEngine({
  forgiving: true,
  simulation: true,
  cache: new Map(),
})

async function initializeHighlighter(langs: LanguageInput[], themes: ThemeInput[]) {
  try {
    return await createHighlighterCore({
      langs,
      themes,
      engine,
    })
  }
  catch (err) {
    console.error('Error initializing highlighter:', err)
    throw err
  }
}

export async function createHighlighter({ langs, themes }: { langs: LanguageInput[], themes: ThemeInput[] }) {
  if (!langs?.length) {
    throw new Error('Please provide languages when creating a highlighter.')
  }

  try {
    const highlighter = await initializeHighlighter(langs, themes)
    return highlighter
  }
  catch (error) {
    console.error('Failed to create highlighter:', error)
    throw error
  }
}

export function processTokens(tokens: ThemedToken[]): TokenType[] {
  return tokens.map(token => ({
    content: token.content,
    color: token.color || '#000000',
    fontStyle: token.fontStyle?.toString(),
  }))
}
