import type { TextStyle } from 'react-native'
import transform from 'css-to-react-native'

export interface HighlighterStyleSheet {
  [key: string]: TextStyle
}

export type ReactStyle = Record<string, TextStyle>

const ALLOWED_STYLE_PROPERTIES: Record<string, boolean> = {
  color: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true,
}

export function convertTokenColorsToReactStyle(tokenColors: any[]): ReactStyle {
  const styleMap: ReactStyle = {}

  tokenColors.forEach((token) => {
    const { scope, settings } = token
    const styleEntries: Array<[string, string]> = []

    if (settings.foreground)
      styleEntries.push(['color', settings.foreground])
    if (settings.background)
      styleEntries.push(['backgroundColor', settings.background])
    if (settings.fontStyle) {
      if (settings.fontStyle.includes('italic'))
        styleEntries.push(['fontStyle', 'italic'])
      if (settings.fontStyle.includes('bold'))
        styleEntries.push(['fontWeight', 'bold'])
    }

    if (styleEntries.length > 0) {
      const transformedStyle = transform(styleEntries.filter(([key]) => ALLOWED_STYLE_PROPERTIES[key]))

      const scopes = Array.isArray(scope) ? scope : [scope]
      scopes.forEach((sc: string) => {
        styleMap[sc] = { ...(styleMap[sc] || {}), ...transformedStyle }
      })
    }
  })

  return styleMap
}

export function getRNStylesFromShikiStyle(theme: any): HighlighterStyleSheet {
  console.log('Converting theme to React Native styles:', theme)
  if (!theme.tokenColors) {
    console.error('Provided theme does not contain \'tokenColors\'.')
    return {}
  }
  const reactStyle = convertTokenColorsToReactStyle(theme.tokenColors)
  console.log('Converted theme to React Native styles:', reactStyle)
  return reactStyle
}
